@@ -6,7 +6,7 @@
 
 #Author: Christos Zamantzas <christos.zamantzas@gmail.com>
 #Contributions: Frank Visser - import, decrypt and encrypt from config file the user variables.
-Version = '0.7-3'
+Version = '0.7-4'
 
 import os
 import sys
@@ -328,6 +328,9 @@ class MyMainWindow(QtGui.QMainWindow):
           QtCore.QObject.connect(self.ui.btnTestGPS2, QtCore.SIGNAL('clicked()'), self.doSendTestGPS2)
           QtCore.QObject.connect(self.ui.btnTestCall, QtCore.SIGNAL('clicked()'), self.doSendTestCall)
           QtCore.QObject.connect(self.ui.btnTestSMS, QtCore.SIGNAL('clicked()'), self.doSendTestSMS)
+          QtCore.QObject.connect(self.ui.btnTestSSH, QtCore.SIGNAL('clicked()'), self.doSendTestSSH)
+          QtCore.QObject.connect(self.ui.btnTestScript, QtCore.SIGNAL('clicked()'), self.doSendTestScript)
+          QtCore.QObject.connect(self.ui.btnTestsDone, QtCore.SIGNAL('clicked()'), self.doStart)
           
           ##Connect Menu Buttons 
           QtCore.QObject.connect(self.ui.actionQuit, QtCore.SIGNAL('triggered()'), QtGui.qApp, QtCore.SLOT('quit()'))
@@ -755,29 +758,37 @@ class MyMainWindow(QtGui.QMainWindow):
           os.system('sudo smscon -test email2')
           message = 'TEST INITIATED: An email with a picture taken with the front camera has been sent.'
           showQuickMessage(message)
-
+          
        def doSendTestGPS1(self):
           os.system('sudo smscon -test gps1')
           message = 'TEST INITIATED: The GPS coordinates will be acquired and will be send once.'
           showQuickMessage(message)
-
+          
        def doSendTestGPS2(self):
           os.system('sudo smscon -test gps2')
           message = 'TEST INITIATED: The GPS coordinates will be acquired and will be send in regular periods.'
           showQuickMessage(message)
-             
+          
        def doSendTestCall(self):
           os.system('sudo smscon -test call')
           message = 'TEST INITIATED: A phonecall to the default number will be initiated.'
           showQuickMessage(message)
-
+          
        def doSendTestSMS(self):
           os.system('sudo smscon -test sms')
           message = 'TEST INITIATED: An SMS to the default number will be send.'
           showQuickMessage(message)
-
-       ##FIXME: add more commands.
-
+          
+       def doSendTestSSH(self):
+          os.system('sudo smscon -test ssh')
+          message = 'TEST INITIATED: The reverse SSH connection has been initiated.'
+          showQuickMessage(message)
+          
+       def doSendTestScript(self):
+          os.system('sudo smscon -test script')
+          message = 'TEST INITIATED: The script has been executed.'
+          showQuickMessage(message)
+          
        def doUpdatePassword(self):
           ##Open Dialog Window - change password
           mydialog = MyPasswordDialog()
